require 'digest/sha1'

class FeedbackBox < ActiveRecord::Base

  ####################
  ### Associations ###
  ####################
  
  belongs_to :user
  has_many :feedback_comments, :dependent => :destroy
  
  ####################
  ### Named Scopes ###
  ####################
  
  default_scope :order => "published_on"
  
  ###################
  ### Validations ###
  ###################
  
  validates_presence_of :user_id, :title, :published_on
  validates_uniqueness_of :widget_id, :unless => Proc.new { |box| box.new_record? }
  
  ###############
  ### Filters ###
  ###############
  
  after_create :create_widget_id
  
  
  private
    def create_widget_id
      self.widget_id = Digest::SHA1.hexdigest("#{self.id}")
      self.save!
    end
end
