require 'test_helper'

class CompanyAdmin::FeedbackBoxesControllerTest < ActionController::TestCase
  setup :activate_authlogic
  
  context "Not logged in as a company admin" do
    should "not be allowed in" do
      
    end
  end
  
  context "A logged in company admin" do
    setup do
      @user = login_as_company_admin
      @feedback_box = Factory(:feedback_box, :user => @user)
    end
    
    context 'gets the index' do
      setup do
        get :index
      end
      
      should_respond_with :success
      should_assign_to :feedback_boxes
    end
    
    context 'gets index with feeback boxes' do
      setup do
        @middle_box = @feedback_box
        @latest_box = Factory.create(:feedback_box, :user => @user, :published_on => (Date.today + 5.days))
        @earliest_box = Factory.create(:feedback_box, :user => @user, :published_on => (Date.today - 5.days))
        get :index
      end
      
      should "be in chronological order by published_on" do
        @boxes = assigns(:feedback_boxes)
        assert_equal @boxes.first, @earliest_box
        assert_equal @boxes.second, @middle_box
        assert_equal @boxes.last, @latest_box
      end
    end
    
    should 'only see own feedback boxes' do
      my_box = @feedback_box
      someone_elses_box = Factory.create(:feedback_box, :user => Factory(:user))
      get :index
      
      my_boxes = assigns(:feedback_boxes)
      assert my_boxes.include?(my_box)
      assert !my_boxes.include?(someone_elses_box)
    end
    
    should "get new" do
      get :new
      assert_response :success
    end

    should "create feedback_box" do
      assert_difference('FeedbackBox.count') do
        post :create, :feedback_box => Factory.attributes_for(:feedback_box)
      end

      assert_redirected_to edit_company_admin_feedback_box_path(assigns(:feedback_box))
    end

    should "show feedback_box" do
      get :show, :id => @feedback_box.to_param
      assert_response :redirect
      assert_redirected_to edit_company_admin_feedback_box_path(assigns(:feedback_box))
    end

    should "get edit" do
      get :edit, :id => @feedback_box.to_param
      assert_response :success
    end

    should "update feedback_box" do
      put :update, :id => @feedback_box.to_param, :feedback_box => { }
      assert_redirected_to edit_company_admin_feedback_box_path(assigns(:feedback_box))
    end

    should "destroy feedback_box" do
      assert_difference('FeedbackBox.count', -1) do
        delete :destroy, :id => @feedback_box.to_param
      end

      assert_redirected_to company_admin_feedback_boxes_path
    end
  end
end
